@@ -15,7 +15,7 @@ int main(int argc,char *argv[]) {
 
     /* create elements */
     for(i=0;i<1000;i++) {
-        if ( (user = malloc(sizeof(example_user_t))) == NULL) exit(-1);
+        if ( (user = (example_user_t*)malloc(sizeof(example_user_t))) == NULL) exit(-1);
         user->id = i;
         user->cookie = i*i;
         if (i<10) HASH_ADD_INT(users,id,user);
@@ -39,4 +39,5 @@ int main(int argc,char *argv[]) {
     HASH_FIND(alth,altusers,&i,sizeof(int),tmp);
     printf("%d %s in alth\n", i, (tmp ? "found" : "not found"));
 
+   return 0;
 }
