@@ -8,8 +8,8 @@
 /* Print a message if the hash's no-expand flag is set. */
 #undef uthash_noexpand_fyi 
 #undef uthash_expand_fyi 
-#define uthash_noexpand_fyi printf("noexpand set\n");
-#define uthash_expand_fyi(tbl) printf("hash expanded (hash_q: %f)\n", ((UT_hash_table*)tbl)->hash_q);
+#define uthash_noexpand_fyi(tbl) printf("noexpand set\n");
+#define uthash_expand_fyi(tbl) printf("hash expanded\n");
 
 typedef struct name_rec {
     char boy_name[BUFLEN];
@@ -31,13 +31,16 @@ int main(int argc,char *argv[]) {
     }
 
     while (fgets(linebuf,BUFLEN,file) != NULL) {
-        if ( (name = malloc(sizeof(name_rec))) == NULL) exit(-1);
+        if ( (name = (name_rec*)malloc(sizeof(name_rec))) == NULL) exit(-1);
         strncpy(name->boy_name,linebuf,BUFLEN);
         HASH_ADD_STR(names,boy_name,name);
     }
 
     fclose(file);
     HASH_SORT(names,namecmp);
-    for(name=names;name;name=name->hh.next) printf("%s",name->boy_name);
+    for(name=names;name;name=(name_rec*)(name->hh.next)) 
+      printf("%s",name->boy_name);
+
+   return 0;
 }
 
