@@ -25,7 +25,7 @@ int main(int argc,char *argv[]) {
 
     while (fgets(linebuf,BUFLEN,file) != NULL) {
         i++;
-        if ( (name = malloc(sizeof(name_rec))) == NULL) exit(-1);
+        if ( (name = (name_rec*)malloc(sizeof(name_rec))) == NULL) exit(-1);
         strncpy(name->boy_name,linebuf,BUFLEN);
         HASH_ADD_STR(names,boy_name,name);
     }
@@ -39,5 +39,6 @@ int main(int argc,char *argv[]) {
     }
     fclose(file);
     printf("lookup on %d of %d names succeeded\n", j, i);
+   return 0;
 }
 
